# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""remove unused metadata.json fields

Revision ID: 731cab3f7cba
Revises: e4452ab33088
Create Date: 2021-05-12 15:24:59.993302

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "731cab3f7cba"
down_revision = "e4452ab33088"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content = E'{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "/tmp/workspaces_tmp/{{relative_path}}",
}'
        WHERE filename = 'metadata.json' AND workflow_name = 'std_calibration'
        """
    )


def downgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "calFiles": {},
  "createTarFile": false,
  "startTime": 0.0,
  "processingSite": "DSOC",
  "applyTelescopeFlags": false,
  "spectralAveraging": 0,
  "timeAveraging": 0,
  "downloadDataFormat": "ASDM",
  "JsonMetadata.WORK_TO_DELIVER": "PRODUCTS",
  "recipientsList": "chausman@nrao.edu",
  "deliveryFormat": "ASDM",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "mostRecentTask": "",
  "destinationDirectory": "/tmp/workspaces_tmp/{{relative_path}}",
  "intentsFileName": "intents_hifv.xml",
  "proceduresFileName": "procedure_hifv.xml",
  "notificationSender": "do-not-reply@nrao.edu",
  "telescope": "VLA",
  "downloadFormat": "asdm",
  "user": "vlapipe",
  "archive": "",
  "intents": "",
  "selectScans": "",
  "ousStatusID": "",
  "projectCodeOrDataType": ""
}'
        WHERE filename = 'metadata.json' AND workflow_name = 'std_calibration'
        """
    )
